@@ -27,6 +27,10 @@ use NewsExtractor::SiteSpecificExtractor::www_upmedia_mg;
 use NewsExtractor::SiteSpecificExtractor::ctee_com_tw;
 use NewsExtractor::SiteSpecificExtractor::news_ebc_net_tw;
 use NewsExtractor::SiteSpecificExtractor::newnet_tw;
+use NewsExtractor::SiteSpecificExtractor::www_thestandnews_com;
+use NewsExtractor::SiteSpecificExtractor::www_hkcnews_com;
+use NewsExtractor::SiteSpecificExtractor::www_epochtimes_com;
+use NewsExtractor::SiteSpecificExtractor::www_ttv_com_tw;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -44,6 +48,9 @@ has extractor => (
 
 use constant {
     SiteSpecificExtractorByHost => {
+        'www.epochtimes.com' => 'NewsExtractor::SiteSpecificExtractor::www_epochtimes_com',
+        'www.hkcnews.com' => 'NewsExtractor::SiteSpecificExtractor::www_hkcnews_com',
+        'www.thestandnews.com' => 'NewsExtractor::SiteSpecificExtractor::www_thestandnews_com',
         'www.allnews.tw' => 'NewsExtractor::SiteSpecificExtractor::www_allnews_tw',
         'www.rvn.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_rvn_com_tw',
         'www.chinatimes.com' => 'NewsExtractor::SiteSpecificExtractor::ChinaTimes',
@@ -72,6 +79,7 @@ use constant {
         'ctee.com.tw' => 'NewsExtractor::SiteSpecificExtractor::ctee_com_tw',
         'news.ebc.net.tw' => 'NewsExtractor::SiteSpecificExtractor::news_ebc_net_tw',
         'newnet.tw' => 'NewsExtractor::SiteSpecificExtractor::newnet_tw',
+        'www.ttv.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ttv_com_tw',
     },
     CSSRuleSetByHost => {
         'www.taiwannews.com.tw' => {
@@ -92,12 +100,6 @@ use constant {
             journalist => '.td-post-author-name',
             content_text => '.td-post-content > span[itemprop=articleBody]',
         },
-        'www.epochtimes.com' => {
-            headline     => 'h1.title',
-            dateline     => 'header[role=heading] time[datetime]',
-            journalist   => '#artbody > p:nth-last-child(4)',
-            content_text => '#artbody p',
-        },
         'www.enewstw.com' =>  {
             headline     => 'td.blog_title > strong',
             dateline     => 'td.blog_title tr:nth-child(2) > td.blog',
