@@ -19,6 +19,11 @@ has site_name => (
     isa => Maybe[Str],
 );
 
+has content_text => (
+    is => "lazy",
+    isa => Str,
+);
+
 no Moo;
 
 sub _build_site_name {
@@ -35,7 +40,6 @@ sub _build_site_name {
 sub headline {
     my ($self) = @_;
 
-    my $site_name = $self->site_name;
     my ($title, $el);
     my $dom = $self->dom;
     if ($el = $dom->at("#story #news_title, #news_are .newsin_title, .data_midlle_news_box01 dl td:first-child")) {
@@ -51,7 +55,7 @@ sub headline {
     }
     $title .= "";
 
-    if ($site_name) {
+    if (my $site_name = $self->site_name) {
         $title =~ s/\s* \p{Punct} \s* $site_name \s* \z//x;
     }
     if (defined($title)) {
@@ -222,7 +226,7 @@ sub journalist {
     return $ret;
 }
 
-sub content_text {
+sub _build_content_text {
     my ($self) = @_;
     my ($el, $html);
 
